---
name: Bug report
about: Create a report to help us improve django-axes
title: 'BUG: Short description of the problem'
labels: 'bug'
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. 
2. 
3. 
4.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Your environment**
python version:
django version:
django-axes version:
Operating system:

**Additional context**
Add any other context about the problem here.

**Possible implementation**
Not obligatory, but suggest an idea for implementing addition or change
